@@ -7,8 +7,9 @@ use Dancer::Plugin;
 use Dancer qw(:syntax);
 
 use HTML::Entities;
+use Scalar::Util qw(blessed reftype);
 
-our $VERSION = '0.11';
+our $VERSION = '0.20';
 
 =head1 NAME
 
@@ -94,9 +95,16 @@ be exempted from automatic escaping - for example:
 
 The above would exclude token names ending in C<_html> from being escaped.
 
+By default, blessed objects being passed to the template will be left
+unmolested, as digging around in the internals of the object is probably not
+wise or desirable.  However, if you do want this to be done, set the
+C<traverse_objects> setting to a true value, and objects will be treated just
+like any other hashref/arrayref.
+
 =cut
 
 my $exclude_pattern;
+my $traverse_objects;
 my %seen;
 
 hook before_template_render => sub {
@@ -109,6 +117,8 @@ hook before_template_render => sub {
         ? qr/$config->{exclude_pattern}/
         : undef;
 
+    $traverse_objects = $config->{traverse_objects};
+
     # flush seen cache
     %seen = ();
 
@@ -129,9 +139,13 @@ sub _encode {
 
     $seen{scalar $in} = 1;
 
-    if (ref $in eq 'ARRAY') {
+    if (ref $in eq 'ARRAY' 
+        or ($traverse_objects && blessed($in) && reftype($in) eq 'ARRAY'))
+    {
         $in->[$_] = _encode($in->[$_]) for (0..$#$in);
-    } elsif (ref $in eq 'HASH') {
+    } elsif (ref $in eq 'HASH' 
+        or ($traverse_objects && blessed($in) && reftype($in) eq 'HASH')) 
+    {
         while (my($k,$v) = each %$in) {
             next if defined $exclude_pattern
                 && $k =~ $exclude_pattern;
